# script to register an API

import requests
from pathlib import Path
import json
import argparse


class Application:
    def __init__(self, base_url, name, scopes="write"):
        self.base_url = base_url
        self.name = name
        self.scopes = scopes
        self.headers = {"Content-Type": "application/json"}

    def register(self):
        app_json = Path(f"./{self.name}_app.json")
        if app_json.is_file():
            print(f"Found {app_json} file")
            print(f"Looks like you've already registered {self.name}")
            return False
        data = {
            "client_name": self.name,
            "redirect_uris": "urn:ietf:wg:oauth:2.0:oob",
            "scopes": self.scopes,
        }
        try:
            response = requests.post(
                f"{self.base_url}/api/v1/apps",
                data=json.dumps(data),
                headers=self.headers,
            )
            response.raise_for_status()
            json_r = response.json()
            self.client_id = json_r["client_id"]
            self.client_secret = json_r["client_secret"]
            print(f"Registered {self.name}, client ID is {self.client_id}")
            with open(app_json, "w") as jfh:
                json.dump(json_r, jfh, indent=2)
                print(f"Wrote response to {app_json}")
            return True
        except Exception as e:
            print("Something went wrong:")
            print(e)
            print(data)
            return False


def cli():
    ap = argparse.ArgumentParser()
    ap.add_argument("-u", "--url", required=True, type=str, help="GoToSocial server")
    ap.add_argument("-n", "--name", required=True, type=str, help="Application name")
    ap.add_argument("-s", "--scopes", default="write", type=str, help="Scope")
    args = ap.parse_args()
    app = Application(args.url, args.name, args.scopes)
    app.register()


if __name__ == "__main__":
    cli()
